import static org.junit.Assert.*;

import org.junit.After;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.ExpectedException;

public class TestCar {

	@Rule
	public ExpectedException exception = ExpectedException.none();
	
	private Car car;

	/*
	 * This method is executed before each test.
	 * 
	 * To establish connections to a database use the @BeforeClass annotation.
	 * A method annotated with @BeforeClass is executed before the construction 
	 * of the test-class. (THIS class, where we are now)
	 */
	@Before
	public void setUp() throws Exception {
		car = new Car("blue", 180, Car.DIESEL_FUEL);
		System.out.println("Car built!");
		System.out.println(car.isBroken);
		System.out.println(car.currentSpeed);
		// Look at the console, the output appears before every test
	}

	/*
	 * This method is executed after each test.
	 * 
	 * To tear down connections to a database use the @AfterClass annotation.
	 * A method annotated with @BeforeClass is executed after all tests are executed.
	 */
	@After
	public void tearDown() throws Exception {
		System.out.println(car.isBroken);
		System.out.println(car.currentSpeed);
		car = null;
		System.out.println("Car destroyed!");
		// Look at the console, the output appears after every test
	}

	@Test
	public void testAccelerate_tooFast() {
		exception.expect(IllegalArgumentException.class);
		car.accelerate(200);
	}
	
	@Test
	public void testAccelerate_tooSlow() {
		exception.expect(IllegalArgumentException.class);
		car.accelerate(-1);
	}
	
	@Test
	public void testAccelerate_Value() {
		car.accelerate(70);
		assertEquals("Sould be 70", 70, car.currentSpeed);
	}

	@Test
	public void testRefuel_ok() {
		String tmp = car.refuel(Car.DIESEL_FUEL);
		assertEquals("Schuld be ok", "Fuel tank full", tmp);
	}
	
	@Test
	public void testRefuel_wrong() {
		String tmp = car.refuel(Car.GASOLINE);
		assertEquals("Schuld break", "Wrong fuel! Car broken!", tmp);
	}

	@Test
	public void testRepairCar() {
		car.repairCar();
		assertFalse(car.isBroken);
	}

}
